@@ -1,30 +1,37 @@
 """
 This is the command line interface for mokapot
 """
+import datetime
+import logging
 import sys
 import time
-import logging
-import datetime
 from functools import partial
 from pathlib import Path
 
 import numpy as np
 
 from . import __version__
-from .config import Config
-from .parsers.pin import read_pin
-from .parsers.pepxml import read_pepxml
-from .parsers.fasta import read_fasta
 from .brew import brew
+from .config import Config
 from .model import PercolatorModel, load_model
+from .parsers.fasta import read_fasta
+from .parsers.pepxml import read_pepxml
+from .parsers.pin import read_pin
+from .plugins import get_plugins
 
 
 def main():
     """The CLI entry point"""
     start = time.time()
+    plugins = get_plugins()
 
     # Get command line arguments
-    config = Config()
+    parser = Config().parser
+    for plugin_name, plugin in plugins.items():
+        parsergroup = parser.add_argument_group(plugin_name)
+        plugin.add_arguments(parsergroup)
+
+    config = Config(parser)
 
     # Setup logging
     verbosity_dict = {
@@ -50,15 +57,22 @@ def main():
     logging.info("")
     logging.info("Starting Analysis")
     logging.info("=================")
+    logging.debug("Loaded plugins: %s", plugins.keys())
 
     np.random.seed(config.seed)
 
     # Parse Datasets
     parse = get_parser(config)
+    enabled_plugins = {p: plugins[p]() for p in config.plugin}
+
     if config.aggregate or len(config.psm_files) == 1:
         datasets = parse(config.psm_files)
+        for plugin in enabled_plugins.values():
+            datasets = plugin.process_data(datasets, config)
     else:
         datasets = [parse(f) for f in config.psm_files]
+        for plugin in enabled_plugins.values():
+            datasets = [plugin.process_data(ds, config) for ds in datasets]
         prefixes = [Path(f).stem for f in config.psm_files]
 
     # Parse FASTA, if required:
@@ -82,9 +96,34 @@ def main():
                 dataset.add_proteins(proteins)
 
     # Define a model:
+    model = None
     if config.load_models:
         model = [load_model(model_file) for model_file in config.load_models]
-    else:
+    elif enabled_plugins:
+        plugin_models = {}
+        for plugin_name, plugin in enabled_plugins.items():
+            model = plugin.get_model(config)
+            if model is not None:
+                logging.debug(f"Loaded model for {plugin_name}")
+                plugin_models[plugin_name] = model
+
+        if not plugin_models:
+            logging.info(
+                "No models were defined by plugins. Using default model."
+            )
+            model = None
+        else:
+            first_mod_name = list(plugin_models.keys())[0]
+            if len(plugin_models) > 1:
+                logging.warning(
+                    "More than one model was defined by plugins."
+                    " Using the first one. (%s)",
+                    first_mod_name,
+                )
+            model = list(plugin_models.values())[0]
+
+    if model is None:
+        logging.debug(f"Loading Percolator model.")
         model = PercolatorModel(
             train_fdr=config.train_fdr,
             max_iter=config.max_iter,
